from setuptools import setup, find_packages

setup(name="hhsqllib",
	  version="0.0",
	  packages=find_packages(),
	  install_requires=[
'addict==2.4.0',
'attrs==23.2.0',
'certifi==2024.6.2',
'charset-normalizer==3.3.2',
'click==8.1.7',
'cloudpickle==3.0.0',
'colorama==0.4.6',
'contourpy==1.2.1',
'cramjam==2.8.3',
'cycler==0.12.1',
'dask==2024.5.2',
'datashape==0.5.2',
'empyrical==0.5.5',
'fastparquet==2024.2.0',
'fonttools==4.51.0',
'fsspec==2024.3.1',
'greenlet==3.0.3',
'idna==3.7',
'importlib_metadata==7.1.0',
'importlib_resources==6.4.0',
'kiwisolver==1.4.5',
'locket==1.0.0',
'lxml==5.2.2',
'matplotlib==3.8.4',
'mssql==1.0.1',
'multipledispatch==1.0.0',
'mysql==0.0.3',
'mysqlclient==2.2.4',
'networkx==3.2.1',
'numpy==1.26.4',
'packaging==24.0',
'pandas==2.2.2',
'pandas-datareader==0.10.0',
'partd==1.4.2',
'pillow==10.3.0',
'pyarrow==16.0.0',
'pymssql==2.3.0',
'PyMySQL==1.1.0',
'pyodbc==5.1.0',
'pyparsing==3.1.2',
'python-dateutil==2.9.0.post0',
'pytz==2024.1',
'PyYAML==6.0.1',
'requests==2.32.3',
'scipy==1.13.1',
'six==1.16.0',
'SQLAlchemy==2.0.30',
'toolz==0.12.1',
'tqdm==4.66.4',
'typing_extensions==4.11.0',
'tzdata==2024.1',
'urllib3==2.2.1',
'zipp==3.18.1'
	  ],
	  author="hh",
	  author_email="hehuang0717@outlook.com",
	  description="sqllib",
	  long_description=open('README.md').read(),
	  long_description_content_type="text/markdown",
	  url="https://your.project.url",
	  classifiers=["Programming Language :: Python :: 3", "License :: OSI Approved :: MIT License",
				   "Operating System :: OS Independent", ],
	  python_requires='>=3.9', )
